@@ -1,5 +1,3 @@
-import warnings
-
 from django.core.exceptions import ImproperlyConfigured
 
 from compressor.filters import FilterBase, CallbackOutputFilter
@@ -15,30 +13,14 @@ class rJSMinFilter(CallbackOutputFilter):
 JSMinFilter = rJSMinFilter
 
 
-class SlimItFilter(CallbackOutputFilter):
-    dependencies = ["slimit"]
-    callback = "slimit.minify"
-    kwargs = {
-        "mangle": True,
-    }
-
-    def __init__(self, *args, **kwargs):
-        warnings.warn(
-            "SlimItFilter is broken in Python 3.6+ and will be removed in "
-            "django-compressor 3.3.",
-            DeprecationWarning,
-        )
-        super().__init__(*args, **kwargs)
-
-
 class CalmjsFilter(FilterBase):
     def __init__(self, *args, **kwargs):
         try:
-            self._parser = kwargs.pop('parser')
+            self._parser = kwargs.pop("parser")
         except KeyError:
             self._parser = None
         try:
-            self._unparser = kwargs.pop('unparser')
+            self._unparser = kwargs.pop("unparser")
         except KeyError:
             self._unparser = None
         super().__init__(*args, **kwargs)
@@ -56,6 +38,6 @@ class CalmjsFilter(FilterBase):
 
     def output(self, **kwargs):
         program = self._parser(self.content)
-        minified = u''.join(part.text for part in self._unparser(program))
+        minified = "".join(part.text for part in self._unparser(program))
         assert isinstance(minified, str)
         return minified
