@@ -1,25 +1,24 @@
-from __future__ import absolute_import
 from django.core.exceptions import ImproperlyConfigured
-from django.utils.encoding import smart_text
+from django.utils.encoding import smart_str
 
 from compressor.parser import ParserBase
 
 
 class BeautifulSoupParser(ParserBase):
-
     def __init__(self, content):
-        super(BeautifulSoupParser, self).__init__(content)
+        super().__init__(content)
         try:
             from bs4 import BeautifulSoup
+
             self.soup = BeautifulSoup(self.content, "html.parser")
         except ImportError as err:
             raise ImproperlyConfigured("Error while importing BeautifulSoup: %s" % err)
 
     def css_elems(self):
-        return self.soup.find_all({'link': True, 'style': True})
+        return self.soup.find_all({"link": True, "style": True})
 
     def js_elems(self):
-        return self.soup.find_all('script')
+        return self.soup.find_all("script")
 
     def elem_attribs(self, elem):
         attrs = dict(elem.attrs)
@@ -37,4 +36,8 @@ class BeautifulSoupParser(ParserBase):
         return elem.name
 
     def elem_str(self, elem):
-        return smart_text(elem)
+        elem_as_string = smart_str(elem)
+        if elem.name == "link":
+            # This makes testcases happy
+            elem_as_string = elem_as_string.replace("/>", ">")
+        return elem_as_string
