@@ -7,15 +7,17 @@ from compressor.parser import ParserBase
 
 
 class Html5LibParser(ParserBase):
-
     def __init__(self, content):
         super().__init__(content)
         import html5lib
+
         self.html5lib = html5lib
 
     def _serialize(self, elem):
         return self.html5lib.serialize(
-            elem, tree="etree", quote_attr_values="always",
+            elem,
+            tree="etree",
+            quote_attr_values="always",
             omit_optional_tags=False,
         )
 
@@ -34,11 +36,12 @@ class Html5LibParser(ParserBase):
             raise ParserError("Error while initializing Parser: %s" % err)
 
     def css_elems(self):
-        return self._find('{http://www.w3.org/1999/xhtml}link',
-                          '{http://www.w3.org/1999/xhtml}style')
+        return self._find(
+            "{http://www.w3.org/1999/xhtml}link", "{http://www.w3.org/1999/xhtml}style"
+        )
 
     def js_elems(self):
-        return self._find('{http://www.w3.org/1999/xhtml}script')
+        return self._find("{http://www.w3.org/1999/xhtml}script")
 
     def elem_attribs(self, elem):
         return elem.attrib
@@ -47,8 +50,8 @@ class Html5LibParser(ParserBase):
         return smart_str(elem.text)
 
     def elem_name(self, elem):
-        if '}' in elem.tag:
-            return elem.tag.split('}')[1]
+        if "}" in elem.tag:
+            return elem.tag.split("}")[1]
         return elem.tag
 
     def elem_str(self, elem):
